resource "kubernetes_deployment" "kubernetes_dashboard_deployment" {
  metadata {
    labels {
      "k8-app" = "kubernetes-dashboard"
    }

    name      = "kubernetes-dashboard"
    namespace = "kube-system"
  }

  spec {
    replicas               = 1
    revision_history_limit = 10

    selector {
      match_labels {
        "k8s-app" = "kubernetes-dashboard"
      }
    }

    template {
      metadata {
        namespace = "kube-system"

        labels {
          "k8s-app" = "kubernetes-dashboard"
        }
      }

      spec {
        service_account_name             = "kubernetes-dashboard"
        termination_grace_period_seconds = 60

        volume {
          name = "${kubernetes_service_account.kubernetes_dashboard_serviceaccount.default_secret_name}"

          secret {
            secret_name = "${kubernetes_service_account.kubernetes_dashboard_serviceaccount.default_secret_name}"
          }
        }

        volume {
          name = "kubernetes-dashboard-certs"

          secret {
            secret_name = "kubernetes-dashboard-certs"
          }
        }

        volume {
          name      = "tmp-volume"
          empty_dir = {}
        }

        container {
          image = "k8s.gcr.io/kubernetes-dashboard-amd64:v1.10.1"
          name  = "kubernetes-dashboard-container"
          args  = ["--auto-generate-certificates"]

          volume_mount {
            mount_path = "/var/run/secrets/kubernetes.io/serviceaccount"
            name       = "${kubernetes_service_account.kubernetes_dashboard_serviceaccount.default_secret_name}"
            read_only  = true
          }

          volume_mount {
            mount_path = "/certs"
            name       = "kubernetes-dashboard-certs"
            read_only  = true
          }

          volume_mount {
            mount_path = "/tmp"
            name       = "tmp-volume"
            read_only  = true
          }

          liveness_probe {
            http_get {
              scheme = "HTTPS"
              path   = "/"
              port   = 8443
            }

            initial_delay_seconds = 30
            timeout_seconds       = 30
          }
        }
      }
    }
  }
}
